@@ -18,7 +18,8 @@ from sentence_transformers import SentenceTransformer, util
 from sklearn.metrics.pairwise import cosine_similarity
 similarity_model = SentenceTransformer('distilbert-base-nli-stsb-mean-tokens')
 
-os.path.join(setup.py, 'data/embeddings.csv')
+path = os.path.dirname(os.path.abspath(__file__))
+file_path = os.path.join(path, "data/embeddings.csv")
 
 #%% 
 #Classification Model
@@ -29,7 +30,7 @@ classifier = pipeline('text-classification', model=model, tokenizer=tokenizer) #
 #%%
 
 def load_embeddings(path):
-    return pd.read_csv('data/embeddings.csv')
+    return pd.read_csv(file_path)
 
 def predict(text_input):
     #running the classification model to predict the classes
